@@ -15,7 +15,6 @@
  * limitations under the License.
  *
  */
-
 use std::collections::HashMap;
 use std::env;
 use std::fs::File;
@@ -25,11 +24,12 @@ use std::time::Duration;
 
 use atty::Stream;
 use clap::{value_parser, ArgAction, ArgMatches, Command};
+use hurl::util::path::ContextDir;
+use hurl_core::ast::Entry;
 
 use crate::cli;
 use crate::cli::CliError;
-use crate::http::ClientOptions;
-use crate::runner::Value;
+use crate::runner::{RunnerOptions, RunnerOptionsBuilder, Value, Verbosity};
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct CliOptions {
@@ -80,18 +80,10 @@ pub enum OutputType {
 }
 
 pub fn app(version: &str) -> Command {
-    let ClientOptions {
-        connect_timeout: default_connect_timeout,
-        max_redirect: default_max_redirect,
-        retry_max_count: default_retry_max_count,
-        timeout: default_timeout,
-        ..
-    } = ClientOptions::default();
-
-    let default_connect_timeout = default_connect_timeout.as_secs();
-    let default_max_redirect = default_max_redirect.unwrap();
-    let default_timeout = default_timeout.as_secs();
-    let default_retry_max_count = default_retry_max_count.unwrap();
+    let default_connect_timeout = Duration::from_secs(300);
+    let default_max_redirect = 50;
+    let default_timeout = Duration::from_secs(300);
+    let default_retry_max_count = 10;
 
     Command::new("hurl")
         .about("Run Hurl file(s) or standard input")
@@ -143,7 +135,7 @@ pub fn app(version: &str) -> Command {
                 .long("connect-timeout")
                 .value_name("SECONDS")
                 .help("Maximum time allowed for connection")
-                .default_value(default_connect_timeout.to_string())
+                .default_value(default_connect_timeout.as_secs().to_string())
                 .value_parser(value_parser!(u64))
                 .num_args(1)
         )
@@ -250,7 +242,7 @@ pub fn app(version: &str) -> Command {
                 .short('m')
                 .value_name("SECONDS")
                 .help("Maximum time allowed for the transfer")
-                .default_value(default_timeout.to_string())
+                .default_value(default_timeout.as_secs().to_string())
                 .allow_hyphen_values(true)
                 .value_parser(value_parser!(u64))
                 .num_args(1)
@@ -684,3 +676,88 @@ pub fn get_strings(matches: &ArgMatches, name: &str) -> Option<Vec<String>> {
 pub fn has_flag(matches: &ArgMatches, name: &str) -> bool {
     matches.get_one::<bool>(name) == Some(&true)
 }
+
+impl CliOptions {
+    pub fn to(&self, filename: &str, current_dir: &Path) -> RunnerOptions {
+        let cacert_file = self.cacert_file.clone();
+        let client_cert_file = self.client_cert_file.clone();
+        let client_key_file = self.client_key_file.clone();
+        let connects_to = self.connects_to.clone();
+        let follow_location = self.follow_location;
+        let verbosity = match (self.verbose, self.very_verbose) {
+            (true, true) => Some(Verbosity::VeryVerbose),
+            (true, _) => Some(Verbosity::Verbose),
+            _ => None,
+        };
+        let insecure = self.insecure;
+        let max_redirect = self.max_redirect;
+        let proxy = self.proxy.clone();
+        let no_proxy = self.no_proxy.clone();
+        let cookie_input_file = self.cookie_input_file.clone();
+        let timeout = self.timeout;
+        let connect_timeout = self.connect_timeout;
+        let user = self.user.clone();
+        let user_agent = self.user_agent.clone();
+        let compressed = self.compressed;
+        let file_root = match self.file_root {
+            Some(ref filename) => Path::new(filename),
+            None => {
+                if filename == "-" {
+                    current_dir
+                } else {
+                    let path = Path::new(filename);
+                    path.parent().unwrap()
+                }
+            }
+        };
+        let context_dir = ContextDir::new(current_dir, file_root);
+        let pre_entry = if self.interactive {
+            Some(cli::interactive::pre_entry as fn(Entry) -> bool)
+        } else {
+            None
+        };
+        let post_entry = if self.interactive {
+            Some(cli::interactive::post_entry as fn() -> bool)
+        } else {
+            None
+        };
+        let fail_fast = self.fail_fast;
+        let to_entry = self.to_entry;
+        let resolves = self.resolves.clone();
+        let retry = self.retry;
+        let retry_interval = self.retry_interval;
+        let retry_max_count = self.retry_max_count;
+        let ignore_asserts = self.ignore_asserts;
+        let ssl_no_revoke = self.ssl_no_revoke;
+
+        let mut bd = RunnerOptionsBuilder::new();
+        bd.cacert_file(cacert_file)
+            .client_cert_file(client_cert_file)
+            .client_key_file(client_key_file)
+            .compressed(compressed)
+            .connect_timeout(connect_timeout)
+            .connects_to(&connects_to)
+            .context_dir(&context_dir)
+            .cookie_input_file(cookie_input_file)
+            .fail_fast(fail_fast)
+            .follow_location(follow_location)
+            .ignore_asserts(ignore_asserts)
+            .insecure(insecure)
+            .max_redirect(max_redirect)
+            .no_proxy(no_proxy)
+            .post_entry(post_entry)
+            .pre_entry(pre_entry)
+            .proxy(proxy)
+            .resolves(&resolves)
+            .retry(retry)
+            .retry_interval(retry_interval)
+            .retry_max_count(retry_max_count)
+            .ssl_no_revoke(ssl_no_revoke)
+            .timeout(timeout)
+            .to_entry(to_entry)
+            .user(user)
+            .user_agent(user_agent)
+            .verbosity(verbosity)
+            .build()
+    }
+}
