@@ -17,33 +17,36 @@
  */
 use std::io::Read;
 use std::str;
+use std::str::FromStr;
 
-use curl::easy;
-use encoding::all::ISO_8859_1;
-use encoding::{DecoderTrap, Encoding};
-use std::time::Instant;
-
-use super::core::*;
-use super::options::ClientOptions;
-use super::request::*;
-use super::request_spec::*;
-use super::response::*;
-use super::{Header, HttpError, Verbosity};
-use crate::cli::Logger;
-use crate::http::ContextDir;
 use base64::engine::general_purpose;
 use base64::Engine;
+use chrono::Utc;
+use curl::easy;
 use curl::easy::{List, SslOpt};
-use std::str::FromStr;
+use encoding::all::ISO_8859_1;
+use encoding::{DecoderTrap, Encoding};
 use url::Url;
 
+use crate::http::certificate::Certificate;
+use crate::http::core::*;
+use crate::http::options::ClientOptions;
+use crate::http::request::*;
+use crate::http::request_spec::*;
+use crate::http::response::*;
+use crate::http::timings::Timings;
+use crate::http::{easy_ext, Call, Header, HttpError, Verbosity};
+use crate::util::logger::Logger;
+use crate::util::path::ContextDir;
+
+/// Defines an HTTP client to execute HTTP requests.
+///
+/// Most of the methods are delegated to libcurl functions, while some
+/// features are implemented "by hand" (like retry, redirection etc...)
 #[derive(Debug)]
 pub struct Client {
-    pub handle: Box<easy::Easy>,
-    pub redirect_count: usize,
-    // Unfortunately, follow-location feature from libcurl can not be used
-    // libcurl returns a single list of headers for the 2 responses
-    // Hurl needs to keep everything.
+    /// The handle to libcurl binding
+    handle: Box<easy::Easy>,
 }
 
 impl Client {
@@ -61,7 +64,6 @@ impl Client {
 
         Client {
             handle: Box::new(h),
-            redirect_count: 0,
         }
     }
 
@@ -72,44 +74,38 @@ impl Client {
         request_spec: &RequestSpec,
         options: &ClientOptions,
         logger: &Logger,
-    ) -> Result<Vec<(Request, Response)>, HttpError> {
+    ) -> Result<Vec<Call>, HttpError> {
         let mut calls = vec![];
 
         let mut request_spec = request_spec.clone();
-        self.redirect_count = 0;
+
+        // Unfortunately, follow-location feature from libcurl can not be used
+        // libcurl returns a single list of headers for the 2 responses
+        // Hurl needs to keep everything.
+        let mut redirect_count = 0;
         loop {
-            let (request, response) = self.execute(&request_spec, options, logger)?;
-            calls.push((request.clone(), response.clone()));
-            if !options.follow_location {
+            let call = self.execute(&request_spec, options, logger)?;
+            let base_url = call.request.base_url()?;
+            let redirect_url = self.get_follow_location(&call.response, &base_url);
+            calls.push(call);
+            if !options.follow_location || redirect_url.is_none() {
                 break;
             }
-
-            let base_url = request.base_url()?;
-            if let Some(url) = self.get_follow_location(&response, &base_url) {
-                logger.debug("");
-                logger.debug(format!("=> Redirect to {url}").as_str());
-                logger.debug("");
-                request_spec = RequestSpec {
-                    method: Method::Get,
-                    url,
-                    headers: vec![],
-                    querystring: vec![],
-                    form: vec![],
-                    multipart: vec![],
-                    cookies: vec![],
-                    body: Body::Binary(vec![]),
-                    content_type: None,
-                };
-
-                self.redirect_count += 1;
-                if let Some(max_redirect) = options.max_redirect {
-                    if self.redirect_count > max_redirect {
-                        return Err(HttpError::TooManyRedirect);
-                    }
+            let redirect_url = redirect_url.unwrap();
+            logger.debug("");
+            logger.debug(format!("=> Redirect to {redirect_url}").as_str());
+            logger.debug("");
+            redirect_count += 1;
+            if let Some(max_redirect) = options.max_redirect {
+                if redirect_count > max_redirect {
+                    return Err(HttpError::TooManyRedirect);
                 }
-            } else {
-                break;
             }
+            request_spec = RequestSpec {
+                method: Method::Get,
+                url: redirect_url,
+                ..Default::default()
+            };
         }
         Ok(calls)
     }
@@ -121,7 +117,7 @@ impl Client {
         request_spec: &RequestSpec,
         options: &ClientOptions,
         logger: &Logger,
-    ) -> Result<(Request, Response), HttpError> {
+    ) -> Result<Call, HttpError> {
         // Set handle attributes that have not been set or reset.
 
         // We force libcurl verbose mode regardless of Hurl verbose option to be able
@@ -129,6 +125,9 @@ impl Client {
         // way to get access to the outgoing headers.
         self.handle.verbose(true).unwrap();
 
+        // Activates the access of certificates info chain after a transfer has been executed.
+        self.handle.certinfo(true).unwrap();
+
         if !options.connects_to.is_empty() {
             let connects = to_list(&options.connects_to);
             self.handle.connect_to(connects).unwrap();
@@ -175,7 +174,7 @@ impl Client {
         self.set_body(request_spec_body);
         self.set_headers(request_spec, options);
 
-        let start = Instant::now();
+        let start = Utc::now();
         let verbose = options.verbosity.is_some();
         let very_verbose = options.verbosity == Some(Verbosity::VeryVerbose);
         let mut request_headers: Vec<Header> = vec![];
@@ -208,9 +207,7 @@ impl Client {
                     // Return all request headers (not one by one)
                     easy::InfoType::HeaderOut => {
                         let mut lines = split_lines(data);
-                        if verbose {
-                            logger.method_version_out(&lines[0]);
-                        }
+                        logger.debug_method_version_out(&lines[0]);
 
                         // Extracts request headers from libcurl debug info.
                         lines.pop().unwrap(); // Remove last empty line.
@@ -317,8 +314,21 @@ impl Client {
             Some(status_line) => self.parse_response_version(status_line)?,
         };
         let headers = self.parse_response_headers(&response_headers);
-        let duration = start.elapsed();
         let length = response_body.len();
+        let certificate = if let Some(cert_info) = easy_ext::get_certinfo(&self.handle)? {
+            match Certificate::try_from(cert_info) {
+                Ok(value) => Some(value),
+                Err(message) => {
+                    logger.error(format!("can not parse certificate - {message}").as_str());
+                    None
+                }
+            }
+        } else {
+            None
+        };
+        let stop = Utc::now();
+        let duration = (stop - start).to_std().unwrap();
+        let timings = Timings::new(&mut self.handle, start, stop);
         self.handle.reset();
 
         let request = Request {
@@ -334,16 +344,17 @@ impl Client {
             body: response_body,
             duration,
             url,
+            certificate,
         };
 
         if verbose {
+            // FIXME: the cast to u64 seems not necessary.
+            //  If we dont cast from u128 and try to format! or println!
+            //  we have a segfault on Alpine Docker images and Rust 1.68.0, whereas it was
+            //  ok with Rust >= 1.67.0.
+            let duration = duration.as_millis() as u64;
             logger.debug_important(
-                format!(
-                    "Response: (received {} bytes in {} ms)",
-                    length,
-                    duration.as_millis()
-                )
-                .as_str(),
+                format!("Response: (received {length} bytes in {duration} ms)").as_str(),
             );
             logger.debug("");
 
@@ -362,7 +373,11 @@ impl Client {
             }
         }
 
-        Ok((request, response))
+        Ok(Call {
+            request,
+            response,
+            timings,
+        })
     }
 
     /// Generates URL.
@@ -678,10 +693,7 @@ impl Header {
         match line.find(':') {
             Some(index) => {
                 let (name, value) = line.split_at(index);
-                Some(Header {
-                    name: name.to_string().trim().to_string(),
-                    value: value[1..].to_string().trim().to_string(),
-                })
+                Some(Header::new(name.trim(), value[1..].trim()))
             }
             None => None,
         }
@@ -736,17 +748,11 @@ mod tests {
     fn test_parse_header() {
         assert_eq!(
             Header::parse("Foo: Bar\r\n").unwrap(),
-            Header {
-                name: "Foo".to_string(),
-                value: "Bar".to_string(),
-            }
+            Header::new("Foo", "Bar")
         );
         assert_eq!(
             Header::parse("Location: http://localhost:8000/redirected\r\n").unwrap(),
-            Header {
-                name: "Location".to_string(),
-                value: "http://localhost:8000/redirected".to_string(),
-            }
+            Header::new("Location", "http://localhost:8000/redirected")
         );
         assert!(Header::parse("Foo").is_none());
     }
