@@ -15,28 +15,29 @@
  * limitations under the License.
  *
  */
-
+pub use self::call::Call;
+pub use self::certificate::Certificate;
 pub use self::client::Client;
-pub use self::context_dir::ContextDir;
 pub use self::cookie::{CookieAttribute, ResponseCookie};
 pub use self::core::{Cookie, Param, RequestCookie};
 pub use self::error::HttpError;
 pub use self::header::Header;
 pub use self::options::{ClientOptions, Verbosity};
 pub use self::request::Request;
-#[cfg(test)]
-pub use self::request_spec::tests::*;
 pub use self::request_spec::{Body, FileParam, Method, MultipartParam, RequestSpec};
-#[cfg(test)]
-pub use self::response::tests::*;
 pub use self::response::{Response, Version};
+#[cfg(test)]
+pub use self::tests::*;
+pub use self::timings::Timings;
 pub use self::version::libcurl_version_info;
 
+mod call;
+mod certificate;
 mod client;
-mod context_dir;
 mod cookie;
 mod core;
 mod debug;
+mod easy_ext;
 mod error;
 mod header;
 mod mimetype;
@@ -50,4 +51,7 @@ mod response;
 mod response_cookie;
 mod response_debug;
 mod response_decoding;
+#[cfg(test)]
+mod tests;
+mod timings;
 mod version;
