@@ -15,12 +15,12 @@
  * limitations under the License.
  *
  */
-
-use super::core::*;
-use super::RequestSpec;
-use crate::http::*;
 use std::collections::HashMap;
 
+use crate::http::core::*;
+use crate::http::{RequestSpec, *};
+use crate::util::path::ContextDir;
+
 impl RequestSpec {
     /// Returns this request as curl arguments.
     /// It does not contain the requests cookies (they will be accessed from the client)
@@ -45,21 +45,21 @@ impl RequestSpec {
                 if content_type.as_str() != "application/x-www-form-urlencoded"
                     && content_type.as_str() != "multipart/form-data"
                 {
-                    arguments.push("-H".to_string());
+                    arguments.push("--header".to_string());
                     arguments.push(format!("'Content-Type: {content_type}'"));
                 }
             } else if !self.body.bytes().is_empty() {
                 match self.body.clone() {
                     Body::Text(_) => {
-                        arguments.push("-H".to_string());
+                        arguments.push("--header".to_string());
                         arguments.push("'Content-Type:'".to_string())
                     }
                     Body::Binary(_) => {
-                        arguments.push("-H".to_string());
+                        arguments.push("--header".to_string());
                         arguments.push("'Content-Type: application/octet-stream'".to_string())
                     }
                     Body::File(_, _) => {
-                        arguments.push("-H".to_string());
+                        arguments.push("--header".to_string());
                         arguments.push("'Content-Type:'".to_string())
                     }
                 }
@@ -71,7 +71,7 @@ impl RequestSpec {
             arguments.push(format!("'{}'", param.curl_arg_escape()));
         }
         for param in self.multipart.clone() {
-            arguments.push("-F".to_string());
+            arguments.push("--form".to_string());
             arguments.push(format!("'{}'", param.curl_arg(context_dir)));
         }
 
@@ -116,7 +116,7 @@ impl Method {
         match self {
             Method::Get => {
                 if data {
-                    vec!["-X".to_string(), "GET".to_string()]
+                    vec!["--request".to_string(), "GET".to_string()]
                 } else {
                     vec![]
                 }
@@ -126,10 +126,10 @@ impl Method {
                 if data {
                     vec![]
                 } else {
-                    vec!["-X".to_string(), "POST".to_string()]
+                    vec!["--request".to_string(), "POST".to_string()]
                 }
             }
-            _ => vec!["-X".to_string(), self.to_string()],
+            _ => vec!["--request".to_string(), self.to_string()],
         }
     }
 }
@@ -139,7 +139,7 @@ impl Header {
         let name = self.name.clone();
         let value = self.value.clone();
         vec![
-            "-H".to_string(),
+            "--header".to_string(),
             encode_shell_string(format!("{name}: {value}").as_str()),
         ]
     }
@@ -234,9 +234,34 @@ fn escape_string(s: &str) -> String {
 
 #[cfg(test)]
 pub mod tests {
-    use super::*;
     use std::path::Path;
 
+    use super::*;
+    use crate::http;
+
+    fn form_http_request() -> RequestSpec {
+        RequestSpec {
+            method: Method::Post,
+            url: "http://localhost/form-params".to_string(),
+            headers: vec![Header::new(
+                "Content-Type",
+                "application/x-www-form-urlencoded",
+            )],
+            form: vec![
+                Param {
+                    name: String::from("param1"),
+                    value: String::from("value1"),
+                },
+                Param {
+                    name: String::from("param2"),
+                    value: String::from("a b"),
+                },
+            ],
+            content_type: Some("multipart/form-data".to_string()),
+            ..Default::default()
+        }
+    }
+
     #[test]
     fn test_encode_byte() {
         assert_eq!(encode_byte(1), "\\x01".to_string());
@@ -248,42 +273,37 @@ pub mod tests {
         assert!(Method::Get.curl_args(false).is_empty());
         assert_eq!(
             Method::Get.curl_args(true),
-            vec!["-X".to_string(), "GET".to_string()]
+            vec!["--request".to_string(), "GET".to_string()]
         );
 
         assert_eq!(
             Method::Post.curl_args(false),
-            vec!["-X".to_string(), "POST".to_string()]
+            vec!["--request".to_string(), "POST".to_string()]
         );
         assert!(Method::Post.curl_args(true).is_empty());
 
         assert_eq!(
             Method::Put.curl_args(false),
-            vec!["-X".to_string(), "PUT".to_string()]
+            vec!["--request".to_string(), "PUT".to_string()]
         );
         assert_eq!(
             Method::Put.curl_args(true),
-            vec!["-X".to_string(), "PUT".to_string()]
+            vec!["--request".to_string(), "PUT".to_string()]
         );
     }
 
     #[test]
     fn header_curl_args() {
         assert_eq!(
-            Header {
-                name: "Host".to_string(),
-                value: "example.com".to_string(),
-            }
-            .curl_args(),
-            vec!["-H".to_string(), "'Host: example.com'".to_string()]
+            Header::new("Host", "example.com").curl_args(),
+            vec!["--header".to_string(), "'Host: example.com'".to_string()]
         );
         assert_eq!(
-            Header {
-                name: "If-Match".to_string(),
-                value: "\"e0023aa4e\"".to_string(),
-            }
-            .curl_args(),
-            vec!["-H".to_string(), "'If-Match: \"e0023aa4e\"'".to_string()]
+            Header::new("If-Match", "\"e0023aa4e\"").curl_args(),
+            vec![
+                "--header".to_string(),
+                "'If-Match: \"e0023aa4e\"'".to_string()
+            ]
         );
     }
 
@@ -327,15 +347,15 @@ pub mod tests {
     fn requests_curl_args() {
         let context_dir = &ContextDir::default();
         assert_eq!(
-            hello_http_request().curl_args(context_dir),
+            http::hello_http_request().curl_args(context_dir),
             vec!["'http://localhost:8000/hello'".to_string()]
         );
         assert_eq!(
             custom_http_request().curl_args(context_dir),
             vec![
-                "-H".to_string(),
+                "--header".to_string(),
                 "'User-Agent: iPhone'".to_string(),
-                "-H".to_string(),
+                "--header".to_string(),
                 "'Foo: Bar'".to_string(),
                 "'http://localhost/custom'".to_string(),
             ]
@@ -349,7 +369,7 @@ pub mod tests {
         assert_eq!(
             form_http_request().curl_args(context_dir),
             vec![
-                "-H".to_string(),
+                "--header".to_string(),
                 "'Content-Type: application/x-www-form-urlencoded'".to_string(),
                 "--data".to_string(),
                 "'param1=value1'".to_string(),
