@@ -15,24 +15,32 @@
  * limitations under the License.
  *
  */
+use chrono::{DateTime, Utc};
+use serde_json::Number;
 
-use crate::cli;
 use crate::http::{
-    Cookie, Header, Param, Request, RequestCookie, Response, ResponseCookie, Version,
+    Call, Certificate, Cookie, Header, Param, Request, RequestCookie, Response, ResponseCookie,
+    Timings, Version,
 };
-use crate::runner::{AssertResult, Call, CaptureResult, EntryResult, HurlResult};
+use crate::runner::{AssertResult, CaptureResult, EntryResult, HurlResult};
+use crate::util::logger;
 
 impl HurlResult {
-    pub fn to_json(&self, content: &str) -> serde_json::Value {
+    /// Serializes an [`HurlResult`] to a JSON representation.
+    ///
+    /// Note: `content` is passed to this method to save asserts and
+    /// errors messages (with lines and columns). This parameter will be removed
+    /// soon and the original content will be accessible through the [`HurlResult`] instance.
+    pub fn to_json(&self, content: &str, filename: &str) -> serde_json::Value {
         let mut map = serde_json::Map::new();
         map.insert(
             "filename".to_string(),
-            serde_json::Value::String(self.filename.clone()),
+            serde_json::Value::String(filename.to_string()),
         );
         let entries = self
             .entries
             .iter()
-            .map(|e| e.to_json(&self.filename, content))
+            .map(|e| e.to_json(filename, content))
             .collect();
         map.insert("entries".to_string(), serde_json::Value::Array(entries));
         map.insert("success".to_string(), serde_json::Value::Bool(self.success));
@@ -77,6 +85,7 @@ impl Call {
         let mut map = serde_json::Map::new();
         map.insert("request".to_string(), self.request.to_json());
         map.insert("response".to_string(), self.response.to_json());
+        map.insert("timings".to_string(), self.timings.to_json());
         serde_json::Value::Object(map)
     }
 }
@@ -121,6 +130,9 @@ impl Response {
         map.insert("headers".to_string(), headers);
         let cookies = self.cookies().iter().map(|e| e.to_json()).collect();
         map.insert("cookies".to_string(), serde_json::Value::Array(cookies));
+        if let Some(certificate) = &self.certificate {
+            map.insert("certificate".to_string(), certificate.to_json());
+        }
         serde_json::Value::Object(map)
     }
 }
@@ -233,6 +245,72 @@ impl ResponseCookie {
     }
 }
 
+impl Certificate {
+    fn to_json(&self) -> serde_json::Value {
+        let mut map = serde_json::Map::new();
+        map.insert(
+            "subject".to_string(),
+            serde_json::Value::String(self.subject.clone()),
+        );
+        map.insert(
+            "issue".to_string(),
+            serde_json::Value::String(self.issuer.clone()),
+        );
+        map.insert("start_date".to_string(), json_date(self.start_date));
+        map.insert("expire_date".to_string(), json_date(self.expire_date));
+        map.insert(
+            "serial_number".to_string(),
+            serde_json::Value::String(self.serial_number.clone()),
+        );
+        serde_json::Value::Object(map)
+    }
+}
+
+impl Timings {
+    fn to_json(&self) -> serde_json::Value {
+        let mut map = serde_json::Map::new();
+        map.insert(
+            "begin_call".to_string(),
+            serde_json::Value::String(self.begin_call.to_string()),
+        );
+        map.insert(
+            "end_call".to_string(),
+            serde_json::Value::String(self.end_call.to_string()),
+        );
+        let value = self.name_lookup.as_micros() as u64;
+        map.insert(
+            "name_lookup".to_string(),
+            serde_json::Value::Number(Number::from(value)),
+        );
+        let value = self.connect.as_micros() as u64;
+        map.insert(
+            "connect".to_string(),
+            serde_json::Value::Number(Number::from(value)),
+        );
+        let value = self.app_connect.as_micros() as u64;
+        map.insert(
+            "app_connect".to_string(),
+            serde_json::Value::Number(Number::from(value)),
+        );
+        let value = self.pre_transfer.as_micros() as u64;
+        map.insert(
+            "pre_transfert".to_string(),
+            serde_json::Value::Number(Number::from(value)),
+        );
+        let value = self.start_transfer.as_micros() as u64;
+        map.insert(
+            "start_transfert".to_string(),
+            serde_json::Value::Number(Number::from(value)),
+        );
+        let value = self.total.as_micros() as u64;
+        map.insert(
+            "total".to_string(),
+            serde_json::Value::Number(Number::from(value)),
+        );
+        serde_json::Value::Object(map)
+    }
+}
+
 impl CaptureResult {
     fn to_json(&self) -> serde_json::Value {
         let mut map = serde_json::Map::new();
@@ -253,7 +331,7 @@ impl AssertResult {
         map.insert("success".to_string(), serde_json::Value::Bool(success));
 
         if let Some(err) = self.error() {
-            let message = cli::error_string_no_color(filename, content, &err);
+            let message = logger::error_string(filename, content, &err, false);
             map.insert("message".to_string(), serde_json::Value::String(message));
         }
         map.insert(
@@ -299,3 +377,7 @@ impl Cookie {
         serde_json::Value::Object(map)
     }
 }
+
+fn json_date(value: DateTime<Utc>) -> serde_json::Value {
+    serde_json::Value::String(value.to_string())
+}
