@@ -18,26 +18,24 @@
 use std::collections::HashMap;
 use std::time::Duration;
 
-use crate::cli::Logger;
-use crate::http;
-use crate::http::ClientOptions;
 use hurl_core::ast::*;
 
-use super::core::*;
-use super::core::{Error, RunnerError};
-use super::request::eval_request;
-use super::response::{eval_asserts, eval_captures};
-use super::value::Value;
-use crate::runner::request::{cookie_storage_clear, cookie_storage_set};
-use crate::runner::response::eval_version_status_asserts;
+use crate::http;
+use crate::http::ClientOptions;
+use crate::runner::core::{Error, RunnerError, *};
+use crate::runner::request::{cookie_storage_clear, cookie_storage_set, eval_request};
+use crate::runner::response::{eval_asserts, eval_captures, eval_version_status_asserts};
 use crate::runner::runner_options::RunnerOptions;
 use crate::runner::template::eval_template;
+use crate::runner::value::Value;
+use crate::util::logger::Logger;
 
-/// Runs an `entry` with `http_client` and returns one or more
-/// [`EntryResult`] (if following redirect).
+/// Runs an `entry` with `http_client` and returns one [`EntryResult`].
 ///
-/// `variables` are used to render values at runtime, and can be updated
-/// by captures.
+/// The `calls` field of the [`EntryResult`] contains a list of HTTP requests and responses that have
+/// been executed. If `http_client` has been configured to follow redirection, the `calls` list contains
+/// every step of the redirection for the first to the last.
+/// `variables` are used to render values at runtime, and can be updated by captures.
 pub fn run(
     entry: &Entry,
     entry_index: usize,
@@ -115,15 +113,14 @@ pub fn run(
     };
 
     // We runs capture and asserts on the last HTTP request/response chains.
-    let (_, http_response) = calls.last().unwrap();
-    let calls: Vec<Call> = calls
+    let call = calls.last().unwrap();
+    let http_response = &call.response;
+    // `time_in_ms` represent the network time of calls, not including assert processing.
+    let time_in_ms = calls
         .iter()
-        .map(|(req, resp)| Call {
-            request: req.clone(),
-            response: resp.clone(),
-        })
-        .collect();
-    let time_in_ms = calls.iter().map(|c| c.response.duration.as_millis()).sum();
+        .map(|call| call.timings.total)
+        .sum::<Duration>()
+        .as_millis();
 
     // We proceed asserts and captures in this order:
     // 1. first, check implicit assert on status and version. If KO, test is failed
