@@ -19,79 +19,75 @@ use std::collections::HashMap;
 use std::thread;
 use std::time::Instant;
 
-use crate::cli::Logger;
-use crate::http;
-use crate::runner::entry::get_entry_verbosity;
-use crate::runner::runner_options::RunnerOptions;
-use crate::runner::Value;
-use crate::util::logger::LoggerBuilder;
 use hurl_core::ast::VersionValue::VersionAnyLegacy;
 use hurl_core::ast::*;
+use hurl_core::error::Error;
+use hurl_core::parser;
 
-use super::core::*;
-use super::entry;
+use crate::http;
+use crate::runner::core::*;
+use crate::runner::runner_options::RunnerOptions;
+use crate::runner::{entry, Value};
+use crate::util::logger::{Logger, LoggerBuilder};
 
-/// Runs a `hurl_file`, issue from the given `filename` file and `content`, with
-/// an `http_client`. Returns a [`HurlResult`] upon completion.
+/// Runs a Hurl `content` and returns a [`HurlResult`] upon completion.
 ///
-/// `filename` and `content` are used to display line base logs (for parsing error or asserts
-/// failures).
 ///
 /// # Example
 ///
 /// ```
 /// use std::collections::HashMap;
-/// use std::path::PathBuf;
-/// use hurl::cli::Logger;
-/// use hurl_core::parser;
-/// use hurl::http;
-/// use hurl::http::ContextDir;
 /// use hurl::runner;
 /// use hurl::runner::{Value, RunnerOptionsBuilder, Verbosity};
 /// use hurl::util::logger::LoggerBuilder;
 ///
-/// // Parse Hurl file
-/// let filename = "sample.hurl";
-/// let s = r#"
+/// // A simple Hurl sample
+/// let content = r#"
 /// GET http://localhost:8000/hello
-/// HTTP/1.0 200
+/// HTTP 200
 /// "#;
-/// let hurl_file = parser::parse_hurl_file(s).unwrap();
 ///
-/// // Create an HTTP client
-/// let mut client = http::Client::new(None);
-/// let mut builder = LoggerBuilder::new();
-/// let logger = builder.filename(filename).content(s).build().unwrap();
-///
-/// // Define runner options
-/// let runner_options = RunnerOptionsBuilder::new()
+/// // Define runner options and logger
+/// let options = RunnerOptionsBuilder::new()
 ///     .follow_location(true)
 ///     .verbosity(Some(Verbosity::Verbose))
 ///     .build();
+/// let logger = LoggerBuilder::new().build();
 ///
-/// // set variables
+/// // Set variables
 /// let mut variables = HashMap::default();
 /// variables.insert("name".to_string(), Value::String("toto".to_string()));
 ///
-/// // Run the hurl file
-/// let hurl_results = runner::run(
-///     &hurl_file,
-///     filename,
-///     &mut client,
-///     &runner_options,
+/// // Run the Hurl sample
+/// let result = runner::run(
+///     content,
+///     &options,
 ///     &variables,
 ///     &logger
 /// );
-/// assert!(hurl_results.success);
+/// assert!(result.unwrap().success);
 /// ```
 pub fn run(
-    hurl_file: &HurlFile,
-    filename: &str,
-    http_client: &mut http::Client,
+    content: &str,
     runner_options: &RunnerOptions,
     variables: &HashMap<String, Value>,
     logger: &Logger,
-) -> HurlResult {
+) -> Result<HurlResult, String> {
+    // Try to parse the content
+    let hurl_file = parser::parse_hurl_file(content);
+    let hurl_file = match hurl_file {
+        Ok(h) => h,
+        Err(e) => {
+            logger.error_rich(content, &e);
+            return Err(e.description());
+        }
+    };
+
+    log_run_info(&hurl_file, runner_options, variables, logger);
+
+    // Now, we have a syntactically correct HurlFile instance, we can run it.
+    let cookie_input_file = runner_options.cookie_input_file.clone();
+    let mut http_client = http::Client::new(cookie_input_file);
     let mut entries = vec![];
     let mut variables = variables.clone();
     let mut entry_index = 1;
@@ -112,15 +108,14 @@ pub fn run(
         // We compute these new overridden options for this entry, before entering into the `run`
         // function because entry options can modify the logger and we want the preamble
         // "Executing entry..." to be displayed based on the entry level verbosity.
-        let entry_verbosity = get_entry_verbosity(entry, &runner_options.verbosity);
-        let mut builder = LoggerBuilder::new();
-        let logger = builder
+        let entry_verbosity = entry::get_entry_verbosity(entry, &runner_options.verbosity);
+        let logger = LoggerBuilder::new()
+            .filename(&logger.filename)
             .color(logger.color)
             .verbose(entry_verbosity.is_some())
-            .filename(logger.filename)
-            .content(logger.content)
-            .build()
-            .unwrap();
+            .test(logger.test)
+            .progress_bar(entry_verbosity.is_none() && logger.progress_bar)
+            .build();
 
         if let Some(pre_entry) = runner_options.pre_entry {
             let exit = pre_entry(entry.clone());
@@ -136,13 +131,15 @@ pub fn run(
 
         warn_deprecated(entry, &logger);
 
+        logger.test_progress(entry_index, n);
+
         let options_result =
             entry::get_entry_options(entry, runner_options, &mut variables, &logger);
         let entry_result = match &options_result {
             Ok(options) => entry::run(
                 entry,
                 entry_index,
-                http_client,
+                &mut http_client,
                 &mut variables,
                 options,
                 &logger,
@@ -186,12 +183,16 @@ pub fn run(
         // we log error on stderr.
         for e in &entry_result.errors {
             if retry {
-                logger.debug_error(e);
+                if logger.verbose {
+                    logger.test_erase_line();
+                    logger.debug_error(content, e);
+                }
             } else {
-                logger.error_rich(e);
+                logger.test_erase_line();
+                logger.error_rich(content, e);
             }
         }
-        entries.push(entry_result.clone());
+        entries.push(entry_result);
 
         if let Some(post_entry) = runner_options.post_entry {
             let exit = post_entry();
@@ -219,17 +220,17 @@ pub fn run(
         retry_count = 1;
     }
 
+    logger.test_erase_line();
+
     let time_in_ms = start.elapsed().as_millis();
     let cookies = http_client.get_cookie_storage();
-    let filename = filename.to_string();
     let success = is_success(&entries);
-    HurlResult {
-        filename,
+    Ok(HurlResult {
         entries,
         time_in_ms,
         success,
         cookies,
-    }
+    })
 }
 
 /// Returns `true` if all the entries ar successful, `false` otherwise.
@@ -257,6 +258,7 @@ fn is_success(entries: &[EntryResult]) -> bool {
 fn warn_deprecated(entry: &Entry, logger: &Logger) {
     // HTTP/* is used instead of HTTP.
     if let Some(response) = &entry.response {
+        let filename = &logger.filename;
         let version = &response.version;
         let source_info = &version.source_info;
         let line = &source_info.start.line;
@@ -264,8 +266,7 @@ fn warn_deprecated(entry: &Entry, logger: &Logger) {
         if version.value == VersionAnyLegacy {
             logger.warning(
                 format!(
-                    "{}:{}:{} 'HTTP/*' keyword is deprecated, please use 'HTTP' instead",
-                    logger.filename, line, column
+                    "{filename}:{line}:{column} 'HTTP/*' keyword is deprecated, please use 'HTTP' instead"
                 )
                 .as_str(),
             );
@@ -282,14 +283,14 @@ fn warn_deprecated(entry: &Entry, logger: &Logger) {
         ..
     } = &entry.request
     {
+        let filename = &logger.filename;
         let source_info = &template.source_info;
         let line = &source_info.start.line;
         let column = &source_info.start.column;
         let template = template.to_string();
         logger.warning(
             format!(
-                "{}:{}:{} '```{}```' request body is deprecated, please use '`{}`' instead",
-                logger.filename, line, column, template, template
+                "{filename}:{line}:{column} '```{template}```' request body is deprecated, please use '`{template}`' instead"
             )
             .as_str(),
         );
@@ -304,16 +305,49 @@ fn warn_deprecated(entry: &Entry, logger: &Logger) {
         ..
     }) = &entry.response
     {
+        let filename = &logger.filename;
         let source_info = &template.source_info;
         let line = &source_info.start.line;
         let column = &source_info.start.column;
         let template = template.to_string();
         logger.warning(
             format!(
-                "{}:{}:{} '```{}```' response body is deprecated, please use '`{}`' instead",
-                logger.filename, line, column, template, template
+                "{filename}:{line}:{column} '```{template}```' response body is deprecated, please use '`{template}`' instead"
             )
             .as_str(),
         );
     }
 }
+
+/// Logs various debug information at the start of `hurl_file` run.
+fn log_run_info(
+    hurl_file: &HurlFile,
+    runner_options: &RunnerOptions,
+    variables: &HashMap<String, Value>,
+    logger: &Logger,
+) {
+    logger.debug_important("Options:");
+    logger.debug(format!("    fail fast: {}", runner_options.fail_fast).as_str());
+    logger.debug(format!("    follow redirect: {}", runner_options.follow_location).as_str());
+    logger.debug(format!("    insecure: {}", runner_options.insecure).as_str());
+    if let Some(n) = runner_options.max_redirect {
+        logger.debug(format!("    max redirect: {n}").as_str());
+    }
+    if let Some(proxy) = &runner_options.proxy {
+        logger.debug(format!("    proxy: {proxy}").as_str());
+    }
+    logger.debug(format!("    retry: {}", runner_options.retry).as_str());
+    if let Some(n) = runner_options.retry_max_count {
+        logger.debug(format!("    retry max count: {n}").as_str());
+    }
+    if !variables.is_empty() {
+        logger.debug_important("Variables:");
+        for (name, value) in variables.iter() {
+            logger.debug(format!("    {name}: {value}").as_str());
+        }
+    }
+    if let Some(to_entry) = runner_options.to_entry {
+        logger
+            .debug(format!("Executing {}/{} entries", to_entry, hurl_file.entries.len()).as_str());
+    }
+}
