@@ -17,18 +17,16 @@
  */
 use std::collections::HashMap;
 use std::ffi::OsStr;
-#[allow(unused)]
-use std::io::prelude::*;
 use std::path::Path;
 
-use crate::http;
-use crate::http::ContextDir;
-use crate::runner::body::eval_file;
 use hurl_core::ast::*;
 
-use super::core::Error;
-use super::template::eval_template;
-use super::value::Value;
+use crate::http;
+use crate::runner::body::eval_file;
+use crate::runner::core::Error;
+use crate::runner::template::eval_template;
+use crate::runner::value::Value;
+use crate::util::path::ContextDir;
 
 pub fn eval_multipart_param(
     multipart_param: &MultipartParam,
