@@ -15,22 +15,19 @@
  * limitations under the License.
  *
  */
+use std::collections::HashMap;
 
 use base64::engine::general_purpose;
 use base64::Engine;
-use std::collections::HashMap;
-#[allow(unused)]
-use std::io::prelude::*;
-
-use crate::http;
-use crate::http::ContextDir;
 use hurl_core::ast::*;
 
-use super::body::eval_body;
-use super::core::Error;
-use super::template::eval_template;
-use super::value::Value;
+use crate::http;
+use crate::runner::body::eval_body;
+use crate::runner::core::Error;
 use crate::runner::multipart::eval_multipart_param;
+use crate::runner::template::eval_template;
+use crate::runner::value::Value;
+use crate::util::path::ContextDir;
 
 /// Transforms an AST `request` to a spec request given a set of `variables`.
 pub fn eval_request(
@@ -44,9 +41,9 @@ pub fn eval_request(
     // Headers
     let mut headers: Vec<http::Header> = vec![];
     for header in &request.headers {
-        let name = header.key.value.clone();
+        let name = &header.key.value;
         let value = eval_template(&header.value, variables)?;
-        let header = http::Header { name, value };
+        let header = http::Header::new(name, &value);
         headers.push(header);
     }
 
@@ -56,9 +53,8 @@ pub fn eval_request(
         let user_password = format!("{}:{}", kv.key.value, value);
         let user_password = user_password.as_bytes();
         let authorization = general_purpose::STANDARD.encode(user_password);
-        let name = "Authorization".to_string();
         let value = format!("Basic {authorization}");
-        let header = http::Header { name, value };
+        let header = http::Header::new("Authorization", &value);
         headers.push(header);
     }
 
@@ -192,14 +188,14 @@ mod tests {
     use super::super::core::RunnerError;
     use super::*;
 
-    pub fn whitespace() -> Whitespace {
+    fn whitespace() -> Whitespace {
         Whitespace {
             value: String::from(" "),
             source_info: SourceInfo::new(0, 0, 0, 0),
         }
     }
 
-    pub fn hello_request() -> Request {
+    fn hello_request() -> Request {
         let line_terminator = LineTerminator {
             space0: whitespace(),
             comment: None,
@@ -236,7 +232,7 @@ mod tests {
         }
     }
 
-    pub fn simple_key_value(key: EncodedString, value: Template) -> KeyValue {
+    fn simple_key_value(key: EncodedString, value: Template) -> KeyValue {
         let line_terminator = LineTerminator {
             space0: whitespace(),
             comment: None,
@@ -253,7 +249,7 @@ mod tests {
         }
     }
 
-    pub fn query_request() -> Request {
+    fn query_request() -> Request {
         let line_terminator = LineTerminator {
             space0: whitespace(),
             comment: None,
@@ -324,7 +320,7 @@ mod tests {
     }
 
     #[test]
-    pub fn test_error_variable() {
+    fn test_error_variable() {
         let variables = HashMap::new();
         let error = eval_request(&hello_request(), &variables, &ContextDir::default())
             .err()
@@ -339,7 +335,7 @@ mod tests {
     }
 
     #[test]
-    pub fn test_hello_request() {
+    fn test_hello_request() {
         let mut variables = HashMap::new();
         variables.insert(
             String::from("base_url"),
@@ -351,7 +347,7 @@ mod tests {
     }
 
     #[test]
-    pub fn test_query_request() {
+    fn test_query_request() {
         let mut variables = HashMap::new();
         variables.insert(
             String::from("param1"),
