@@ -15,7 +15,7 @@
  * limitations under the License.
  *
  */
-use super::json;
+use crate::ast::json;
 
 ///
 /// Hurl AST
@@ -336,6 +336,10 @@ pub enum QueryValue {
     Bytes {},
     Sha256 {},
     Md5 {},
+    Certificate {
+        space0: Whitespace,
+        attribute_name: CertificateAttributeName,
+    },
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -384,6 +388,15 @@ impl CookieAttributeName {
     }
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum CertificateAttributeName {
+    Subject,
+    Issuer,
+    StartDate,
+    ExpireDate,
+    SerialNumber,
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Predicate {
     pub not: bool,
@@ -481,6 +494,7 @@ pub enum PredicateFuncValue {
     IsString {},
     IsCollection {},
     Exist {},
+    IsEmpty {},
 }
 
 //
@@ -873,6 +887,12 @@ pub struct Filter {
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum FilterValue {
     Count,
+    DaysAfterNow,
+    DaysBeforeNow,
+    Format {
+        space0: Whitespace,
+        fmt: Template,
+    },
     HtmlEscape,
     HtmlUnescape,
     Nth {
@@ -893,6 +913,10 @@ pub enum FilterValue {
         space0: Whitespace,
         sep: Template,
     },
+    ToDate {
+        space0: Whitespace,
+        fmt: Template,
+    },
     ToInt,
     UrlDecode,
     UrlEncode,
