@@ -16,11 +16,10 @@
  *
  */
 use crate::ast::*;
-
-use super::error::*;
-use super::primitives::*;
-use super::reader::Reader;
-use super::ParseResult;
+use crate::parser::error::*;
+use crate::parser::primitives::*;
+use crate::parser::reader::Reader;
+use crate::parser::ParseResult;
 
 pub fn parse(reader: &mut Reader) -> ParseResult<'static, Expr> {
     // let start = p.state.clone();
@@ -79,13 +78,12 @@ fn variable_name(reader: &mut Reader) -> ParseResult<'static, Variable> {
 
 #[cfg(test)]
 mod tests {
-    use crate::ast::Pos;
-
     use super::*;
+    use crate::ast::Pos;
 
     #[test]
     fn test_expr() {
-        let mut reader = Reader::init("{{ name}}");
+        let mut reader = Reader::new("{{ name}}");
         assert_eq!(
             parse(&mut reader).unwrap(),
             Expr {
@@ -107,7 +105,7 @@ mod tests {
 
     #[test]
     fn test_expr_error() {
-        let mut reader = Reader::init("{{host>}}");
+        let mut reader = Reader::new("{{host>}}");
         let error = parse(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 7 });
         assert_eq!(
@@ -121,7 +119,7 @@ mod tests {
 
     #[test]
     fn test_expr_error_eof() {
-        let mut reader = Reader::init("{{host");
+        let mut reader = Reader::new("{{host");
         let error = parse(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 7 });
         assert_eq!(
@@ -135,7 +133,7 @@ mod tests {
 
     #[test]
     fn test_variable() {
-        let mut reader = Reader::init("name");
+        let mut reader = Reader::new("name");
         assert_eq!(
             variable_name(&mut reader).unwrap(),
             Variable {
@@ -144,7 +142,7 @@ mod tests {
             }
         );
 
-        let mut reader = Reader::init("my-id");
+        let mut reader = Reader::new("my-id");
         assert_eq!(
             variable_name(&mut reader).unwrap(),
             Variable {
