@@ -52,6 +52,9 @@ pub fn filter(reader: &mut Reader) -> ParseResult<'static, Filter> {
     let value = choice(
         &[
             count_filter,
+            days_after_now_filter,
+            days_before_now_filter,
+            format_filter,
             html_decode_filter,
             html_encode_filter,
             nth_filter,
@@ -59,6 +62,7 @@ pub fn filter(reader: &mut Reader) -> ParseResult<'static, Filter> {
             replace_filter,
             split_filter,
             to_int_filter,
+            to_date_filter,
             url_decode_filter,
             url_encode_filter,
         ],
@@ -87,6 +91,23 @@ fn count_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
     Ok(FilterValue::Count)
 }
 
+fn days_after_now_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
+    try_literal("daysAfterNow", reader)?;
+    Ok(FilterValue::DaysAfterNow)
+}
+
+fn days_before_now_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
+    try_literal("daysBeforeNow", reader)?;
+    Ok(FilterValue::DaysBeforeNow)
+}
+
+fn format_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
+    try_literal("format", reader)?;
+    let space0 = one_or_more_spaces(reader)?;
+    let fmt = quoted_template(reader)?;
+    Ok(FilterValue::Format { space0, fmt })
+}
+
 fn html_encode_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
     try_literal("htmlEscape", reader)?;
     Ok(FilterValue::HtmlEscape)
@@ -132,6 +153,13 @@ fn split_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
     Ok(FilterValue::Split { space0, sep })
 }
 
+fn to_date_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
+    try_literal("toDate", reader)?;
+    let space0 = one_or_more_spaces(reader)?;
+    let fmt = quoted_template(reader)?;
+    Ok(FilterValue::ToDate { space0, fmt })
+}
+
 fn to_int_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
     try_literal("toInt", reader)?;
     Ok(FilterValue::ToInt)
@@ -149,14 +177,13 @@ fn url_decode_filter(reader: &mut Reader) -> ParseResult<'static, FilterValue> {
 
 #[cfg(test)]
 mod tests {
+    use super::*;
     use crate::ast::Pos;
     use crate::parser::ParseError;
 
-    use super::*;
-
     #[test]
     fn test_count() {
-        let mut reader = Reader::init("count");
+        let mut reader = Reader::new("count");
         assert_eq!(
             filter(&mut reader).unwrap(),
             Filter {
@@ -168,7 +195,7 @@ mod tests {
 
     #[test]
     fn test_error() {
-        let mut reader = Reader::init("xcount");
+        let mut reader = Reader::new("xcount");
         let err = filter(&mut reader).err().unwrap();
         assert_eq!(
             err.inner,
@@ -179,7 +206,7 @@ mod tests {
         assert_eq!(err.pos, Pos { line: 1, column: 1 });
         assert!(err.recoverable);
 
-        let mut reader = Reader::init("regex 1");
+        let mut reader = Reader::new("regex 1");
         let err = filter(&mut reader).err().unwrap();
         assert_eq!(
             err.inner,
