@@ -16,12 +16,10 @@
  *
  */
 use crate::ast::*;
-
-use super::error::*;
-use super::expr;
-use super::primitives::*;
-use super::reader::Reader;
-use super::ParseResult;
+use crate::parser::error::*;
+use crate::parser::primitives::*;
+use crate::parser::reader::Reader;
+use crate::parser::{expr, ParseResult};
 
 pub fn url(reader: &mut Reader) -> ParseResult<'static, Template> {
     // Can not be json-encoded, nor empty.
@@ -141,7 +139,7 @@ mod tests {
 
     #[test]
     fn test_url() {
-        let mut reader = Reader::init("http://google.fr # ");
+        let mut reader = Reader::new("http://google.fr # ");
         assert_eq!(
             url(&mut reader).unwrap(),
             Template {
@@ -158,7 +156,7 @@ mod tests {
 
     #[test]
     fn test_url2() {
-        let mut reader = Reader::init("http://localhost:8000/cookies/set-session-cookie2-valueA");
+        let mut reader = Reader::new("http://localhost:8000/cookies/set-session-cookie2-valueA");
         assert_eq!(
             url(&mut reader).unwrap(),
             Template {
@@ -177,7 +175,7 @@ mod tests {
 
     #[test]
     fn test_url_with_expression() {
-        let mut reader = Reader::init("http://{{host}}.fr ");
+        let mut reader = Reader::new("http://{{host}}.fr ");
         assert_eq!(
             url(&mut reader).unwrap(),
             Template {
@@ -214,7 +212,7 @@ mod tests {
 
     #[test]
     fn test_url_error_variable() {
-        let mut reader = Reader::init("http://{{host>}}.fr");
+        let mut reader = Reader::new("http://{{host>}}.fr");
         let error = url(&mut reader).err().unwrap();
         assert_eq!(
             error.pos,
@@ -235,7 +233,7 @@ mod tests {
 
     #[test]
     fn test_url_error_missing_delimiter() {
-        let mut reader = Reader::init("http://{{host");
+        let mut reader = Reader::new("http://{{host");
         let error = url(&mut reader).err().unwrap();
         assert_eq!(
             error.pos,
@@ -255,7 +253,7 @@ mod tests {
 
     #[test]
     fn test_url_error_empty() {
-        let mut reader = Reader::init(" # eol");
+        let mut reader = Reader::new(" # eol");
         let error = url(&mut reader).err().unwrap();
         assert_eq!(error.pos, Pos { line: 1, column: 1 });
         assert_eq!(error.inner, ParseError::UrlIllegalCharacter(' '));
@@ -317,7 +315,7 @@ mod tests {
         ];
         for s in valid_urls {
             //eprintln!("{}", s);
-            let mut reader = Reader::init(s);
+            let mut reader = Reader::new(s);
             assert!(url(&mut reader).is_ok());
         }
     }
